@@ -3,7 +3,7 @@ package MIME::WordDecoder;
 
 =head1 NAME
 
-MIME::WordDecoder - decode RFC-1522 encoded words to a local representation
+MIME::WordDecoder - decode RFC 2047 encoded words to a local representation
 
 
 =head1 SYNOPSIS
@@ -245,6 +245,7 @@ sub decode {
 	### Get the data and (upcased) charset:
 	my $data    = $_->[0];
 	my $charset = (defined($_->[1]) ? uc($_->[1]) : 'raw');
+	$charset =~ s/\*\w+\Z//;   ### RFC2184 language suffix
 
 	### Get the handler; guess if never seen before:
 	defined($self->{MWD_Map}{$charset}) or
@@ -398,7 +399,7 @@ sub h_utf8 {
     local $_    = $_[0];
 #   my $unknown = $_[2]->{MWDI_Unknown};
     my $latin1 = ($_[2]->{MWDI_Num} == 1);
-    print STDERR "UTF8 in:  <$_>\n"; 
+    #print STDERR "UTF8 in:  <$_>\n"; 
 
     my $tgt = '';
     while (m{\G(
@@ -414,7 +415,7 @@ sub h_utf8 {
         else                           { $tgt .= "\x00" }
     }
 
-    print STDERR "UTF8 out: <$tgt>\n"; 
+    #print STDERR "UTF8 out: <$tgt>\n"; 
     $tgt;
 }
 
@@ -425,7 +426,7 @@ sub h_utf16 {
     local $_    = $_[0];
 #   my $unknown = $_[2]->{MWDI_Unknown};
     my $latin1 = ($_[2]->{MWDI_Num} == 1);
-    print STDERR "UTF16 in:  <$_>\n"; 
+    #print STDERR "UTF16 in:  <$_>\n"; 
 
     my $tgt = '';
     while (m{\G(
@@ -440,7 +441,7 @@ sub h_utf16 {
         else                           { $tgt .= "\x00" }
     }
 
-    print STDERR "UTF16 out: <$tgt>\n"; 
+    #print STDERR "UTF16 out: <$tgt>\n"; 
     $tgt;
 }
 
@@ -573,11 +574,6 @@ for (1..15) {
     $DecoderFor{"ISO-8859-$_"} = MIME::WordDecoder::ISO_8859->new($_);
 }
 
-{ 
-  package main; no strict; local $^W = 0;
-  my @x = <::DATA>;
-  eval join('',<::DATA>) || die $@ unless caller();
-}
 1;           # end the module
 __END__
 
@@ -585,11 +581,7 @@ __END__
 =head1 AUTHOR
 
 Eryq (F<eryq@zeegee.com>), ZeeGee Software Inc (F<http://www.zeegee.com>).
-
-
-=head1 VERSION
-
-$Revision: 5.402 $ $Date: 2000/11/12 05:44:57 $
+David F. Skoll (dfs@roaringpenguin.com) http://www.roaringpenguin.com
 
 =cut
 
